@@ -28,6 +28,8 @@
 #include "foreign.h"
 #include "swap_bytes.h"
 #include <errno.h>
+#include "to_bigend.h"
+#include "ibm2ieee.h"
 
 /* double cnxptiee(double from, int fromtype, int totype); */
 
